#[non_exhaustive]pub enum SubmitBlocker {
ValidationErrors,
ParseErrors,
PendingValidation,
InFlightSubmission,
StaleSubmitValidation,
}Expand description
A known reason a submission is unavailable or one submission attempt was refused.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ValidationErrors
Stored validation errors currently block submission.
ParseErrors
Mounted input bindings currently have parse errors.
PendingValidation
Required validation is currently pending.
InFlightSubmission
A submission has started and has not completed yet.
StaleSubmitValidation
The Submit Validation Token presented by an attempt no longer applies to current form state.
This is an attempt outcome rather than a standing form condition, so
SubmitAvailability never contains it. Submit the current draft again to validate it and
obtain a current authorization.